# Relocate
**Do you want to organise your files?** <br>
Then **_Relocate_** is here to help you. It will organise your files as per your requirement.  <br><br>
Install the module from your command prompt.<br>
`pip install relocate`  <br>
To import the RELOCATE package, run the following. <br>
`import relocate`  <br><br>
Now you can group your files, based on the following options.
### relocate.relocateNow()
It will organise your files in separate folders, according to month of last modification and then according to extension.
### relocate.byMonthCreated()
It will organise your files in separate folders, according to month of creation (for Windows) or according to month of last metadata change (for Unix).
### relocate.byYearCreated()
It will organise your files in separate folders, according to year of creation.
### relocate.byMonthModified()
It will organise your files in separate folders, according to month of last modification.
### relocate.byYearModified()
It will organise your files in separate folders, according to year of last modification.
### relocate.byMonthLastAccessed()
It will organise your files in separate folders, according to month of last access.
### relocate.byYearLastAccessed()
It will organise your files in separate folders, according to year of last access.
### relocate.byExtension()
It will organise your files in separate folders, according to file extension.
### relocate.bySize()
It will organise your files in separate folders, according to file size.
### relocate.byFirstChar()
It will organise your files in separate folders, according to first character of file name.  <br><br>

Navigate to the RELOCATED folder,  and you will get your files in an organised manner.  <br><br>

**Do you want to undo the changes?** <br>
Then navigate to RELOCATE folder, and run the following.
### relocate.undo()
It will undo the changes. You will get all your files in this RELOCATED folder. <br><br>
<br>
For any queries, contact me on [LinkedIn](https://www.linkedin.com/in/sandip-palit/)

<hr>

# Changelog:
### Version 2.1.0
* Added **relocate.undo()**
### Version 2.0.0
* Added **relocate.byMonthCreated()**
* Added **relocate.byYearCreated()**
* Added **relocate.byMonthModified()**
* Added **relocate.byYearModified()**
* Added **relocate.byMonthLastAccessed()**
* Added **relocate.byYearLastAccessed()**
* Added **relocate.byExtension()**
* Added **relocate.bySize()**
* Added **relocate.byFirstChar()**
### Version 1.3.1 , 1.3.0 , 1.2.0
* Added **relocate.relocateNow()**
* Bug Fixed

